netapp_ontap.models.aggregate_warning_action API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.aggregate_warning_action`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class AggregateWarningActionSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the AggregateWarningAction object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `arguments GET POST PATCH`

    Arguments present in the specified action message.

  `code GET POST PATCH`

    Corrective action code of the specified action.

  `message GET POST PATCH`

    Specifies the corrective action to be taken to resolve the issue.